Class: LiteParse::TextItem

Inherits:
Object
  • Object
show all
Defined in:
lib/liteparse/types.rb

Overview

A single item of text with spatial position information.

Instance Method Summary collapse

Instance Method Details

#confidenceFloat?

Returns OCR/text extraction confidence (0.0–1.0), if available.

Returns:

  • (Float, nil)

    OCR/text extraction confidence (0.0–1.0), if available



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#font_nameString?

Returns Name of the font used, if available.

Returns:

  • (String, nil)

    Name of the font used, if available



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#font_sizeFloat?

Returns Font size in points, if available.

Returns:

  • (Float, nil)

    Font size in points, if available



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#heightFloat

Returns Height of the text bounding box.

Returns:

  • (Float)

    Height of the text bounding box



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#textString

Returns The text content of this item.

Returns:

  • (String)

    The text content of this item



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#widthFloat

Returns Width of the text bounding box.

Returns:

  • (Float)

    Width of the text bounding box



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#xFloat

Returns Left edge X coordinate of the text bounding box.

Returns:

  • (Float)

    Left edge X coordinate of the text bounding box



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end

#yFloat

Returns Top edge Y coordinate of the text bounding box.

Returns:

  • (Float)

    Top edge Y coordinate of the text bounding box



24
# File 'lib/liteparse/types.rb', line 24

class TextItem; end