Class: LiteParse::TextItem
- Inherits:
-
Object
- Object
- LiteParse::TextItem
- Defined in:
- lib/liteparse/types.rb
Overview
A single item of text with spatial position information.
Instance Method Summary collapse
-
#confidence ⇒ Float?
OCR/text extraction confidence (0.0–1.0), if available.
-
#font_name ⇒ String?
Name of the font used, if available.
-
#font_size ⇒ Float?
Font size in points, if available.
-
#height ⇒ Float
Height of the text bounding box.
-
#text ⇒ String
The text content of this item.
-
#width ⇒ Float
Width of the text bounding box.
-
#x ⇒ Float
Left edge X coordinate of the text bounding box.
-
#y ⇒ Float
Top edge Y coordinate of the text bounding box.
Instance Method Details
#confidence ⇒ Float?
Returns OCR/text extraction confidence (0.0–1.0), if available.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#font_name ⇒ String?
Returns Name of the font used, if available.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#font_size ⇒ Float?
Returns Font size in points, if available.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#height ⇒ Float
Returns Height of the text bounding box.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#text ⇒ String
Returns The text content of this item.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#width ⇒ Float
Returns Width of the text bounding box.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#x ⇒ Float
Returns Left edge X coordinate of the text bounding box.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |
#y ⇒ Float
Returns Top edge Y coordinate of the text bounding box.
24 |
# File 'lib/liteparse/types.rb', line 24 class TextItem; end |